@@ -31,7 +31,7 @@ int getfiletime(const char *filename, curl_off_t *stamp);
   (defined(_WIN32) && (SIZEOF_CURL_OFF_T >= 8))
 void setfiletime(curl_off_t filetime, const char *filename);
 #else
-#define setfiletime(a,b,c) tool_nop_stmt
+#define setfiletime(a, b) tool_nop_stmt
 #endif
 
 #endif /* HEADER_CURL_TOOL_FILETIME_H */
